@@ -2,8 +2,8 @@
  * This is GNU Go, a Go program. Contact gnugo@gnu.org, or see       *
  * http://www.gnu.org/software/gnugo/ for more information.          *
  *                                                                   *
- * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 and 2007 *
- * by the Free Software Foundation.                                  *
+ * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007,   *
+ * 2008 and 2009 by the Free Software Foundation.                    *
  *                                                                   *
  * This program is free software; you can redistribute it and/or     *
  * modify it under the terms of the GNU General Public License as    *
@@ -386,7 +386,7 @@ void add_expand_moyo_move(int pos);
 void add_strategical_attack_move(int pos, int dr);
 void add_strategical_defense_move(int pos, int dr);
 void add_worthwhile_threat_move(int pos);
-void add_replacement_move(int from, int to);
+void add_replacement_move(int from, int to, int color);
 
 /* Parameters to add_either_move and add_all_move */
 #define ATTACK_STRING  1
