@@ -2,8 +2,8 @@
  * This is GNU Go, a Go program. Contact gnugo@gnu.org, or see       *
  * http://www.gnu.org/software/gnugo/ for more information.          *
  *                                                                   *
- * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 and 2007 *
- * by the Free Software Foundation.                                  *
+ * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007,   *
+ * 2008 and 2009 by the Free Software Foundation.                    *
  *                                                                   *
  * This program is free software; you can redistribute it and/or     *
  * modify it under the terms of the GNU General Public License as    *
@@ -692,7 +692,7 @@ unconditional_move_reasons(int color)
       }
       else {
 	TRACE("%1m unconditionally replaced to %1m.\n", pos, replacement_move);
-	add_replacement_move(pos, replacement_move);
+	add_replacement_move(pos, replacement_move, color);
       }
     }
 }
