@@ -2,8 +2,8 @@
  * This is GNU Go, a Go program. Contact gnugo@gnu.org, or see       *
  * http://www.gnu.org/software/gnugo/ for more information.          *
  *                                                                   *
- * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 and 2007 *
- * by the Free Software Foundation.                                  *
+ * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007,   *
+ * 2008 and 2009 by the Free Software Foundation.                    *
  *                                                                   *
  * This program is free software; you can redistribute it and/or     *
  * modify it under the terms of the GNU General Public License as    *
@@ -407,8 +407,8 @@ main(int argc, char *argv[])
 # This is GNU Go, a Go program. Contact gnugo@gnu.org, or see       #\n\
 # http://www.gnu.org/software/gnugo/ for more information.          #\n\
 #                                                                   #\n\
-# Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 and 2007 #\n\
-# by the Free Software Foundation.                                  #\n\
+# Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007,   #\n\
+# 2008 and 2009 by the Free Software Foundation.                    #\n\
 #                                                                   #\n\
 # This program is free software; you can redistribute it and/or     #\n\
 # modify it under the terms of the GNU General Public License as    #\n\
