@@ -1,29 +1,30 @@
 #!/usr/bin/perl
 
-# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
-# This program is distributed with GNU Go, a Go program.        #
-#                                                               #
-# Write gnugo@gnu.org or see http://www.gnu.org/software/gnugo/ #
-# for more information.                                         #
-#                                                               #
-# Copyright 1999, 2000, 2001, 2002, 2003, 2004                  #
-# by the Free Software Foundation.                              #
-#                                                               #
-# This program is free software; you can redistribute it and/or #
-# modify it under the terms of the GNU General Public License   #
-# as published by the Free Software Foundation - version 2.     #
-#                                                               #
-# This program is distributed in the hope that it will be       #
-# useful, but WITHOUT ANY WARRANTY; without even the implied    #
-# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR       #
-# PURPOSE.  See the GNU General Public License in file COPYING  #
-# for more details.                                             #
-#                                                               #
-# You should have received a copy of the GNU General Public     #
-# License along with this program; if not, write to the Free    #
-# Software Foundation, Inc., 59 Temple Place - Suite 330,       #
-# Boston, MA 02111, USA.                                        #
-# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
+# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
+# This program is distributed with GNU Go, a Go program.            #
+#                                                                   #
+# Write gnugo@gnu.org or see http://www.gnu.org/software/gnugo/     #
+# for more information.                                             #
+#                                                                   #
+# Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007    #
+# and 2008 by the Free Software Foundation.                         #
+#                                                                   #
+# This program is free software; you can redistribute it and/or     #
+# modify it under the terms of the GNU General Public License       #
+# as published by the Free Software Foundation - version 3          #
+# or (at your option) any later version.                            #
+#                                                                   #
+# This program is distributed in the hope that it will be           #
+# useful, but WITHOUT ANY WARRANTY; without even the implied        #
+# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR           #
+# PURPOSE.  See the GNU General Public License in file COPYING      #
+# for more details.                                                 #
+#                                                                   #
+# You should have received a copy of the GNU General Public         #
+# License along with this program; if not, write to the Free        #
+# Software Foundation, Inc., 51 Franklin Street, Fifth Floor,       #
+# Boston, MA 02111, USA.                                            #
+# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
 # Here is a perlscript regress.pl. Its purpose is to run
 # the regression tests that are currently implemented with
@@ -134,7 +135,7 @@ my $one_gg_process = 0;
 my @failed_links;
 my @FAILED_links;
 
-my @counters = qw/life_node owl_node reading_node trymove/;
+my @counters = qw/connection_node owl_node reading_node trymove/;
 
 my %counters;
 
@@ -446,8 +447,8 @@ sub regress_file {
         #print "NOT SKIPPING: $next_cmd\n";
 	$top_moves = "";
 	if ($do_topmove) {
-	  if ($next_cmd =~ /gg_genmove\s+([blackwhite])+/) {
-	    $next_cmd =~ s/gg_genmove\s+([blackwhite]+)/top_moves_$1/;
+	  if ($next_cmd =~ /reg_genmove\s+([blackwhite])+/) {
+	    $next_cmd =~ s/reg_genmove\s+([blackwhite]+)/top_moves_$1/;
 	    $top_moves = 1;
 	  }
 	}
@@ -611,7 +612,7 @@ sub eat_board {
   my $no_dragon_data = 0;
   my %stones;
 
-  if ($prev_cmd =~ /gg_genmove/) {
+  if ($prev_cmd =~ /reg_genmove/) {
     #FIXME: There may be other commands that won't require dragon_data
     #to be regenerated.  Better might be to provide a way to query the
     #engine whether dragon_data is currently available w/out regenerating.
@@ -680,7 +681,7 @@ sub eat_board {
     }
   }
   
-  if ($prev_cmd =~ /^[0-9]*\s*gg_genmove/) {
+  if ($prev_cmd =~ /^[0-9]*\s*reg_genmove/) {
     if (! ($next_cmd =~ /^#\?\s*\[(!)?\(?(.*)\)?\]\*?\s*$/)) {
       print "BAD TEST: $next_cmd\n";
     }
@@ -700,7 +701,7 @@ sub eat_board {
       $stones{$result} .= ";try_wrong;";
     }
   } else {
-    # Experimental - should work for gg_genmove too!
+    # Experimental - should work for reg_genmove too!
     if (! ($next_cmd =~ /^#\?\s*\[(!)?\(?(.*)\)?\]\*?\s*$/)) {
       print "BAD TEST: $next_cmd\n";
     }  #see commend on this regex above.
@@ -757,7 +758,7 @@ sub eat_board {
   }
 
   my %tmarr;
-  if ($prev_cmd =~ /.*gg_genmove\s+([whiteblack]+)/) {
+  if ($prev_cmd =~ /.*reg_genmove\s+([whiteblack]+)/) {
     go_command ("top_moves");
     my $top_moves = <$goprog_out>;
     <$goprog_out>;
